Monty Python's Flying Circus: Just the Words - Episode 42

# Episode Forty-two: Light entertainment war

'Up Your Pavement'
RAF banter
Trivializing the war
Courtmartial
Basingstoke in Westphalia
'Anything Goes In' (song)
Film trailer
The public are idiots
Programme titles conference
The last five miles of the M2
Woody and tinny words
Show-jumping (musical)
Newsflash (germans)
'When Does A Dream Begin?' (song)

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A high street. Musical theme played on a banjo a la 'Steptoe and Son' opening. Cut to a tracking shot of two tramps walking jauntily along. They are very arch, over-the-top jolly fellows. They nod at the occasional passer-by and do mock bows to a city gent.
| TITLE CAPTION: 'UP YOUR PAVEMENT' CAPTION: 'BY THE REV. AND MRS A. G. PHIPPS' CAPTION: 'FROM AN IDEA BY LORD CARRINGTON'
| They come to a litter bin, root in it, and one of them produces a newspaper. He hands it to the other, looks in again and brings out a pork pie. He looks in again, his eyes light up, and he produces a bottle of champagne. He passes it to his mate. He looks in again and finds two highly polished glasses. Meanwhile over all this and as they set off down the road together we hear:
Voice Over | Taking life as it comes, sharing the good things and the bad things, finding laughter and fun wherever they go - it is with these two happy-go-lucky rogues that our story begins. (by this time the tramps have walked out of shot; cut to a shot of a sports car up on the pavement with the legs of the two tramps sticking out from underneath; the music turns more urgent and transatlantic) For it is they who were run over by Alex Diamond ... (appropriate music; a James Bond character climbs out of the car and looks down at the dead tramps) international crime fighter ... (shot of him rushing into a film premiere past photographers with flashing bulbs) and playboy ... (cut to him on yacht) fast-moving ... tough-talking ... (still of him with Henry Kissenger; cut to him striding down a street) and just one of the many hundreds of famous people who suffer from lumbago, the epidemic disease about which no one knows more than this man ... (we see him go into a doorway; cut to a low angle close up of Dr Koning donning gloves prior to the operation; the music changes to the Kildare theme) Dr Emile Koning ... doctor ... surgeon ... proctologist ... and selfless fighter against human suffering, whose doorbell (cut to a doorbell and pan down) was the one above the hero of our story tonight ... (pan down to find the doorbell and name) Rear-Admiral Humphrey De Vere! (the door opens and the rear-admiral comes striding out; naval music; he walks up the road) Yes! This is the story of Rear-Admiral Humphrey De Vere ... or rather, the story of his daughter ... (cut to a still of a young inspired and devoted nurse; the music instantly changes to the heroic) For it was her courage, foresight and understanding that enabled us to probe beneath the sophisticated veneer of ... (mix to impressive college grounds) the Royal Arsenal Women's College, Bagshot ... (zoom in across lawns towards the college building) and learn the true story of this man ... (the camera suddenly veers off away from college and homes in on a solitary bush from which appears a seedy fellow in a terrible lightweight suit of several years ago that has got all stained and creased around the crutch) Len Hanky! Chiropodist, voyeur, hen-teaser. The man of whom the chairman of Fiat once said...
| Cut to a high-powered Italian businessman at a desk in a very modern casa-type Italian office.
Chairman | Che cosa è lo succiacatori do polli?
| SUPERIMPOSED CAPTION: What is a hen-teaser? The phone rings. He answers it dynamically and we zoom in on his tense, alert, executive face.
Voice Over | Yes! Tonight we examine the career of Gino Agnelli! The man who started from nothing to build up one of the greatest firms in Europe. (mix through to stock film of a big car-producing plant) And whose telescope was bought from the shop part-owned by a man who, at the age of eight, stole a penknife from the son of this man's brother's housekeeper's dental hygienist's uncle. (as each of these things is mentioned we see a momentary flash of a still of each) The Reverend Charlie `Drooper' Hyper-Squawk Smith (at this point the freeze frame starts moving as the chaplain lifts himself out of the cockpit and jumps down beside his Spitfire) the cleft-palated RAF chaplain, who single-handed shot down over five hundred German chaplains. (smiling cheerfully he crosses off another emblem of a vicar in a German helmet on the side of the plane. Beside this is written '"Here we come Kraut" Luke 17, verse 3') This is the story of the men who flew with him ... it really is! (a squadron leader, just off a mission, runs past, and dashes into a Nissen hut)
| CAPTION: 'SOMEWHERE IN ENGLAND, 1944' The squadron leader enters an RAF officers' mess and takes off his helmet.
Bovril | Morning, Squadron Leader.
Squadron Leader | What-ho, Squiffy.
Bovril | How was it?
Squadron Leader | Top-hole. Bally Jerry, pranged his kite right in the how's your father. Hairy blighter, dicky-birdied, feathered back on his Sammy, took a waspy, flipped over on his Betty Harper's and caught his can in the Bertie.
Bovril | Er, I'm afraid I don't quite follow you, Squadron Leader.
Squadron Leader | It's perfectly ordinary banter, Squiffy. Bally Jerry...pranged his kite right in the how's yer father...hairy blighter, dicky-birdied, feathered back on his Sammy, took a waspy, flipped over on his Betty Harper's and caught his can in the Bertie.
Bovril | No, I'm just not understanding banter at all well today. Give us it slower.
Squadron Leader | Banter's not the same if you say it slower, Squiffy.
Bovril | Hold on then. (shouts) Wingco!
Wingco | Yes!
Bovril | Bend an ear to the Squadron Leader's banter for a sec, would you?
Wingco | Can do.
Bovril | Jolly good.
Wingco | Fire away.
Squadron Leader | (draws a deep breath and looks slightly uncertain, then starts even more deliberately than before) Bally Jerry...pranged his kite...right in how's yer father...hairy blighter...dicky-birdied...feathered back on his Sammy...took a waspy...flipped over on his Betty Harper's and caught his can in the Bertie...
Wingco | ...No, don't understand that banter at all.
Squadron Leader | Something up with my banter, chaps?
| A siren goes. The door bursts open and an out-of-breath young pilot rushes in in his flying gear.
Pilot | Bunch of monkeys on the ceiling, sir! Grab your egg and fours and let's get the bacon delivered!
| General incomprehension. They look at each other.
Wingco | Do you understand that?
Squadron Leader | No, didn't get a word of it.
Wingco | Sorry old man, we don't understand your banter.
Pilot | You know...bally ten-penny ones dropping in the custard...(searching for words) un...Charlie Choppers chucking a handful...
Wingco | No, no...sorry.
Bovril | Say it a bit slower, old chap.
Pilot | Slower banter, sir?
Wingco | Ra-ther!
Pilot | Um...sausage squad up the blue end?
Squadron Leader | No, still don't get it.
Pilot | Um...cabbage crates coming over the briny?
Squadron Leader | No.
Others | No, no....
| Stock film of a German bombing raid.
Voice Over | But by then it was too late. The first cabbage crates hit London on July the 7th. That was just the beginning.
| Cut to a Whitehall war office conference room. A general is on the phone. Four other generals sit there.
General | Five shillings a dozen? That's ordinary cabbages, is it? And what about the bombs?... Good Lord, they are expensive.
| A corporal rushes in.
Corporal | Sir!
General | Yes, what is it?
Corporal | News from the Western Front, sir.
General | Yes ... ?
Corporal | Big enemy attack at dawn, sir ...
General | Yes ... ?
Corporal | Well, the enemy were all wearing little silver halos, sir ... and ... they had fairy wands with big stars on the end ... and ...
General | They what ... ?
Corporal | .. and ... they had spiders in matchboxes, sir.
General | (in disbelief) Good God! How did our chaps react?
Corporal | Well, they were jolly interested, sir. Some of them ... I think it was the 4th Armoured Brigade, sir, they ... well, they went and had a look at the spiders, sir.
General | Oh my God! All right, thank you, Shirley.
| A girl emerges from under the table. She is a blonde WAAF.
Corporal | Sir!
General | (to a sergeant) Get me the Prime Minister. (the sergeant opens the door, Churchill stands outside) Not that quickly! (the sergeant shuts the door) Gentlemen, it's now quite apparent that the enemy are not only fighting this war on the cheap, but they're also not taking it seriously.
Ageing General | Bastards ...
General | First they drop cabbages instead of decent bombs ...
Corporal | The crates were probably quite expensive, sir.
General | Quiet, critic! And now they're doing very silly things in one of the most vital areas of the war!
Ageing General | What are we going to do, Shirley?
General | Well, we've got to act fast before it saps morale. We're going to show these Chinese ...
Captain | Germans, sir.
General | These Germans ... we're going to show them that no British soldier will descend to their level. Anyone found trivialising this war will face the supreme penalty that military law can provide. (he holds a heroic pose; there is a pause during which we expect to cut; we don't; suddenly he breaks out of the pose into informality) That was all right, I think?
Captain | (getting out drinks) Seemed to go quite well.
| Cut to a courtroom in the 1940s. A courtmartial is in progress. An elderly general presides, with two others on either side of him. There is a defense counsel, a prosecutor, a clerk of court, and two men guarding the prisoner.
Presiding General | Sapper Walters, you stand before this court accused of carrying on the war by other than warlike means - to wit, that you did on April 16th, 1942, dress up as a bag of dainties, flick wet towels at the enemy during an important offensive ...
Walters | Well, sir ...
Presiding General | Shut up! Colonel Fawcett for the prosecution ...
Fawcett | Sir, we all know ...
Presiding General | Shut up!
Fawcett | I'm sorry?
Presiding General | Carry on.
Fawcett | Sir, we all know the facts of this case; that Sapper Walters, being in possession of expensive military equipment, to wit one Lee Enfield .303 rifle and 72 rounds of ammunition, valued at a hundred and forty pounds three shillings and sixpence, chose instead to use wet towels to take an enemy command post in the area of Basingstoke ...
Presiding General | Basingstoke? Basingstoke in Hampshire?
Fawcett | No, no, no, sir, no.
Presiding General | I see, carry on.
Fawcett | The result of his action was that the enemy ...
Presiding General | Basingstoke where?
Fawcett | Basingstoke in Westphalia, sir.
Presiding General | Oh I see. Carry on.
Fawcett | The result of Sapper Walters's action was that the enemy received wet patches upon their trousers and in some cases small red strawberry marks upon their thighs ...
Presiding General | I didn't know there was a Basingstoke in Westphalia.
Fawcett | (slightly irritated) It's on the map, sir.
Presiding General | What map?
Fawcett | (more irritably) The map of Westphalia as used by the army, sir.
Presiding General | Well, I've certainly never heard of Basingstoke in Westphalia.
Fawcett | (patiently) It's a municipal borough sir, twenty-seven miles north-north east of Southhampton. Its chief manufactures ...
Presiding General | What ... Southhampton in Westphalia?
Fawcett | Yes sir ... bricks ... clothing. Nearby are remains of Basing House, burned down by Cromwell's cavalry in 1645 ...
Presiding General | Who compiled this map?
Fawcett | Cole Porter, sir.
Presiding General | (incredulously) Cole Porter ... who wrote `Kiss Me Kate'?
Fawcett | No, alas not, sir ... this was Cole Porter who wrote `Anything Goes'. Sir, I shall seek to prove that the man before this court ...
Presiding General | That's the same one! (he sings) `In olden days a glimpse of stocking ...'
Fawcett | I beg your pardon, sir?
Presiding General | (singing) `In olden days a glimpse of stocking, was looked on as something shocking, now heaven knows, anything goes ...'
Fawcett | No, this one's different, sir.
Presiding General | How does it go?
Fawcett | What, sir?
Presiding General | How does your `Anything Goes' go?
Walters | Can I go home now?
Presiding General | Shut up! (to Fawcett) Come on!
Fawcett | Sir, really, this is rather ...
Presiding General | Come on, how does your `Anything Goes' go?
Fawcett | (clearing his throat and going into an extraordinary tuneless and very loud song) Anything goes in. Anything goes out! Fish, bananas, old pyjamas, Mutton! Beef! and Trout! Anything goes in ...
Presiding General | No, that's not it ... carry on.
Fawcett | With respect sir, I shall seek to prove that the man before you in the dock being in the possession of the following: one pair of army boots, value three pounds seven and six, one pair of serge trousers, value two pounds three and six, one pair of gaiters value sixty-eight pounds ten shillings, one ...
Presiding General | Sixty-eight pounds ten shillings for a pair of gaiters?
Fawcett | (dismissively) They were special gaiters, sir.
Presiding General | Special gaiters?
Fawcett | Yes, sir, they were made in France. One beret costing fourteen shillings, one pair of ...
Presiding General | What was special about them?
Fawcett | Oh ... (as if he can hardly be bothered to reply) they were made of a special fabric, sir. The buckles were made of empire silver instead of brass. The total value of the uniform was there ...
Presiding General | Why was the accused wearing special gaiters?
Fawcett | (irritably) They were a presentation pair sir, from the regiment. The total value of the uniform ...
Presiding General | Why did they present him with a special pair of gaiters?
Fawcett | Sir, it seems to me totally irrelevant to the case whether the gaiters were presented to him or not, sir.
Presiding General | I think the court will be able to judge that for themselves. I want to know why the regiment presented the accused with a special pair of gaiters.
Fawcett | (stifling his impatience) He ... used to do things for them. The total value ...
Presiding General | What things?
Fawcett | (exasperated) He .. he used to oblige them, sir. The total value ...
Presiding General | Oblige them?
Fawcett | Yes, sir. The total value of the uniform ...
Presiding General | How did he oblige them?
Fawcett | What sir?
Presiding General | How did he oblige them?
Fawcett | (more and more irritated) He ... um ... used to make them happy in little ways, sir. The total value of the uniform could therefore not have been less than ...
Presiding General | Did he touch them at all?
Fawcett | Sir! I submit that this is totally irrelevant.
Presiding General | I want to know how he made them happy.
Fawcett | (losing his temper) He used to ram things up their ...
Presiding General | (quickly) All right! All right! No need to spell it out! What er ... what has the accused to say?
Walters | (taken off guard) What, me?
Presiding General | Yes. What have you got to say?
Walters | What can I say? I mean, how can I encapsulate in mere words my scorn for any military solution? The fultility of modern warfare? And the hypocrisy by which contemporary government applies one standard to violence within the community and another to violence perpetrated by one community upon another?
Defense Counsel | I'm sorry, but my client has become pretentious. I will say in his defense that he has suffered ...
Fawcett | Sir! We haven't finished the prosecution!
Presiding General | Shut up! I'm in charge of this court. (to the court) Stand up! (everyone stands up) Sit down! (everyone sits down) Go moo! (everyone goes moo; the presiding general turns to Fawcett) See? Right, now, on with the pixie hats! (everyone puts on pixie hats with large pointed ears) And order in the skating vicar. (a skating vicar and everyone bursts into song)
Everyone | Anything goes in. Anything goes out! Fish, bananas, old pyjamas, Mutton! Beef! and Trout! Anything goes in. Anything goes out. (etc.)
| Cut to the coast of Norway. Night. Tense music. Shots of big coastal guns, cliff-top fortifications.
| SUPERIMPOSED CAPTIONS: 'DRAMA!' ' ACTION!'
| Build up for abut ten seconds. Cut to a cliff top looking out to sea. A grappling hook comes over and sticks in, then another, and another. Whispered voices, music, the tension rises as the rope is tightened. Then over the top comes a German, head blackened and camouflaged. Then others climb over; they are wearing haloes, pink tutus, jackboots, wands. They charge over. Stock film of guns blazing.
Voice Over | Yes! Coming to this cinema soon! (cut to stock film of a destroyer in the midst of a pitched sea-battle; victory-at-sea music) The tender compassionate story of one man's love for another man in drag. (cut to a sailor on a ship in rough sea; he calls to the captain who is in an evening gown) THRILL! to the excitement of a night emission over Germany.
| SUPERIMPOSED CAPTION: 'THRILL!'
| Cut to stock shots of bombers on a night raid. Cut to interior of a bomber. Various shots of pilot and navigator. There is flak outside and explosions occasionally light up the cabin.
Voice Over | When the pilot, Jennifer (shot of the pilot) has to choose between his secret love for Louis, (shot of the navigator) the hot-bloodedly bi-sexual navigator and Andy, (shot of the rear gunner) the rear gunner, who, though quite assertive with girls, tends to take the submissive role in his relationships with men. (cut to close up of gritty pipe-smoking RAF top brass) And sensational Mexican starlet, Rosetta Nixon, plays the head of bomber command, (insert of WAAF) whose passion for sea-birds ends in tragedy. (cut to montage of war footage, explosions, guns firing, etc.) With Ginger, as the half-man, half-woman, parrot whose unnatural instincts brought forbidden love in the aviary. And Roger as Pip, the half-parrot, half-man, half-woman, three-quarter badger, ex-bigamist negro preacher, for whom banjo-playing was very difficult, and he never mastered it although he took several courses and went to banjo college ... er ... and everything ... don't miss it!
| During this last lot are superimposed in quick succession the following captions: 'DRAMA' 'SUSPENSE' 'THRILLS' 'MARQUETRY' 'ADVENTURES' 'DON'T MISS IT' 'COMING TO YOUR CINEMA SOON'
Voice Over | Coming to your cinema soon! (cut to an Indian restaurant) Only five minutes from this restaurant! But now!
| Cut to the nude organist (Terry J) and `It's' man.
It's Man | It's ...
| Opening titles At the end of the title cut to tramps exactly as at the beginning of the show. Then cut to two twin-set-and-pearls ladies, Mrs Elizabeth III and Mrs Mock Tudor. They are in a sitting room with vulgar furnishings. By the TV, which they are watching, stands a small Arab boy (Terry G) . He has electrodes fixed to him and wires stretching from a control box held by Mrs Elizabeth III. They are watching the tramps.
Mrs Mock Tudor | Bloody repeats!
| She presses the switch. The arab boy flinches with pain and turns and switches of the TV set.
Mrs Elizabeth III | Yes, repeats or war films. It really makes you want to micturate.
Mrs Mock Tudor | People on television treat the general public like idiots.
Mrs Elizabeth III | Well we are idiots.
Mrs Mock Tudor | Oh no we are not!
Mrs Elizabeth III | Well I am.
Mrs Mock Tudor | How do you know you're an idiot?
Mrs Elizabeth III | Oh, I can show you!
Mrs Mock Tudor | How?
Mrs Elizabeth III | Look!
| Cut to Mrs Elizabeth III coming out of the front door in a fairly well-to-do mock Tudor detached house in its own grounds. She runs headlong into a tree opposite the front door. Repeat a few times. Then she rushes into a field, digs a hole three feet deep and stands in it. Cut to her standing beside a letter box. She straps on a long false nose and pokes it through the letter box. She drinks a delicate cup of tea at a posh café and eats the whole cup. Cut to her nailing something to a lorry. The lorry starts off to reveal that she had been nailing herself to the lorry. She is dragged away. Cut to TV planners at a window, watching Mrs Elizabeth III doing silly things in a car park below them. She has a cream bun hanging from a long stick which comes out of her hat. She walks along strangely.
Chief Executive | You see the public are idiots ... (he has a conference tag on his lapel which reads `Chief TV Planner'; he turns from the window to a conference table, piled with drinks) Yes ... you might just as well show them the last five miles of the M2 ... they'd watch it, eh?
| Cut to Mrs Mock Tudor and Mrs Elizabeth III watching TV. There is a film of the motorway on it, filmed from the bank beside a bridge.
Mrs Mock Tudor | At last they done been put on something interesting.
Mrs Elizabeth III | Oh, most interesting.
| Cut back to the programme planners conference.
First Planner | (reading figures) ... and our figures show that the motorways are extremely popular. I mean, last time we showed a repeat of the Leicester bypass our ratings gave us 97,300,912, and ITV nought. So I do feel we ought to give B roads their own series.
Chief Executive | I'm sorry ... we just can't give you a bigger budget.
Second Planner | Budgie?
First Planner | (to the second planner) No, he's left I think. (to the senior executive) Why not?
Chief Executive | We're not the only slice of the cake, you know.
Third Planner | Wouldn't mind a slice of cake. Nice chocolate cake ... delicious ...
Second Planner | I had a budgie once you know, amusing little chap, used to stick his head in a bell ... what was his name, now ... Joey? ... Xerxes? ...
First Planner | We could repeat them ...
Third Planner | Re-heat them?
First Planner | No, repeat them ...
Third Planner | You don't re-heat cakes. Not chocolate cakes.
Chief Executive | What, repeat the cakes?
Second Planner | Mr Heath, that was the name of the budgie.
Chief Executive | (looking at his watch) Good Lord, the bar's open! (they all scramble madly to their feet) Oh no it isn't, I was looking at the little hand that goes round very fast ...
All | Damn. Blast.
| They sit down again reluctantly. There is a short pause.
First Planner | I've got it. We can retitle the repeats.
Second Planner | What ... give them different names?
Chief Executive | Wouldn't that mean retitling them?
Third Planner | Brilliant!
Chief Executive | Right - all we need is new titles. And they must be damned new!
Second Planner | How about `Dad's Navy'?
Chief Executive | Mm, good, good.
First Planner | `Up Your Mother Next Door.'
Chief Executive | Even better ...
Third Planner | 'Doctor At Bee'!
All | What?
| There is a knock at the door.
First Planner | Someone's knocking at the door.
Chief Executive | Quite like it - bit long, though, I think.
Third Planner | Far too long.
Second Planner | `I Married Lucy.'
Chief Executive | Hasn't that been done?
Second Planner | Oh, yes, a long time ago, though, they'd never remember it.
Third Planner | `Doctor at Three'!
Chief Executive | What?
| There is a knock at the door.
First Planner | I think someone's knocking at the door.
Chief Executive | That's even longer!
Second Planner | `I Married A Tree.'
Chief Executive | `And Mother Makes Tree.'
Third Planner | `Doctor At Cake'!
| Continuous knocking on the door.
First Planner | Look! I'm not absolutely certain, but, well I do rather get the impression that there is someone actually knocking on the door at this very moment.
Chief Executive | That's ridiculous. Half the programme gone. Stop lengthening it!
Third Planner | (desperate) `I Married A Cake'?
Second Planner | (over excited) `I Married Three Rabbit Jelly Moulds'!
Third Planner | Prefer a cake ... specially chocky cake ...
| There is by now a constant hammering.
Security Man | (yells from outside door) Open the sodding door!
Chief Executive | No, no. You can't say `sodding' on the television.
| All shake their heads. The door is broken in. Enter a neo-fascist-looking security man in a wheelchair with an oriental sword through his head.
Chief Executive | You're supposed to knock!
Security Man | Sorry, sir, but there's trouble at studio five!
Second Planner | You're in security, aren't you?
Security Man | Yes, sir.
Second Planner | (triumphantly) Well, you're not allowed to suggest programme titles. (he smiles victoriously at others)
Security Man | Sir! It's the World War series in studio five - they're not taking it seriously any more.
First Planner | You're not allowed to suggest programme titles!
Security Man | (switching on a TV set) Look!
| They rush to the monitor. One of them brushes the oriental sword which is through his head.
Security Man | Ow! Mind me war wound!
All | That's it! Very good title!
| On the screen we see the court martial in progress as we saw it earlier in the show, with the whole court singing.
Everyone | Anything goes in. Anything goes out! Fish, bananas, old pyjamas, Mutton, beef and trout! Anything goes in. Anything goes out! etc.
| ANIMATION: 'What a lovely day'. Exterior, a large, tasteful, Georgian rich person's house with extensive gardens beautifully tended, croquet hoops on the lawn - all in superb taste, nothing vulgar. The sun shines tastefully. The atmosphere is calm. Birds sing. Sound of lawnmovers and cricket in the distance. Laughter from the tennis court. Sound of gardener sharpening spades in the potting shed. Out of vision, a Red Indian struggles to free himself from the rope bonds that bind him. We hear 'Where does a dream begin' being played on a cracked record.
CAPTION: | '1942
| EGYPT
| ECUADOR
| ETHIOPIA
| ENGLAND'
The caption fades and we cut to an upper-clas drawing room. Father, mother and daughter having tea. Four motionless servants stand behind them.
Father | I say...
Daughter | Yes, Daddy?
Father | Croquet hoops look damn pretty this afternoon.
Daughter | Frightfully damn pretty.
Mother | They're coming along awfully well this year.
Father | Yes, better than your Aunt Lavinia's croquet hoops.
Daughter | Ugh! - dreadful tin things.
Mother | I did tell her to stick to wood.
Father | Yes, you can't beat wood...Gorn!
Mother | What's gorn dear?
Father | Nothing, nothing, I just like the word, it gives me confidence. Gorn...gorn.It's got a sort of woody quality about it. Gorn. Gorn. Much better than 'newspaper' or 'litterbin'.
Daughter | Frightful words!
Mother | Perfectly dreadful!
Father | Ugh! Newspaper!...litterbin...dreadful tinny sort of words. Tin, tin, tin.
| The daughter bursts into tears.
Mother | Oh, dear, don't say 'tin' to Rebecca, you know how it upsets her.
Father | (to the daughter) Sorry, old horse.
Mother | Sausage!
Father | Sausage...there's a good woody sort of word, 'sausage'...gorn.
Daughter | Antelope!
Father | Where? On the lawn? (he picks up a rifle)
Daughter | No, no, daddy...just the word.
Father | Don't want an antelope nibbling the hoops.
Daughter | No, antelope...sort of nice and woody type of thing.
Mother | Don't think so, Becky old chap.
Father | No, no 'antelope', 'antelope' - tinny sort of word. (the daughter bursts into tears) Oh, sorry old man.
Mother | Really, Mansfield.
Father | Well, she's got to come to terms with these things... seemly... prodding... vacuum... leap...
Daughter | (miserably) Hate 'leap'.
Mother | Perfectly dreadful.
Daughter | Sort of PVC-y sort of word, don't you know.
Mother | Lower-middle.
Father | Bound!
Mother | Now you're talking!
Father | Bound...Vole...Recidivist.
Mother | Bit tinny. (the daughter howls) Oh! Sorry, Becky old beast. (the daughter runs out crying)
Father | Oh dear, I suppose she'll be gorn for a few days now.
Mother | Caribou!
Father | Splendid word.
Mother | No, dear...nibbling the hoops.
Father | (he fires a shot) Caribou gorn.
Mother | (laughs politely)
Father | Intercourse.
Mother | Later, dear.
Father | No, no, the word, 'intercourse' - good and woody...Inter...course... pert...pert thighs...botty, botty botty... (the mother leaves the room)...erogenous...zone...concubine...erogenous zone! Loose woman...erogenous zone...(the mother returns and throws a bucket of water over him) Oh, thank you, dear...you know, it's a funny thing, dear...all the naughty words sound woody.
Mother | Really, dear?...how about tit?
Father | Oh dear, I hadn't thought about that. Tit. Tit. Oh, that's very tinny, isn't it? (the daughter returns) Ugh! Tinny, tinny...(the daughter runs out crying) Oh dear...ocelot...wasp....yowling...Oh dear, I'm bored...I'd better go and have a bath, I suppose.
Mother | Oh really, must you, dear? You've had nine today.
Father | All right, I'll sack one of the servants...Simpkins!...nasty tinny sort of name. Simpkins! (he exits)
| A pilot from the RAF banter scene enters.
Pilot | I say, mater, cabbage crates coming over the briny.
Mother | (frowns and shakes her head) Sorry dear, don't understand.
Pilot | Er...cow-catchers creeping up on the conning towers...
Mother | No...sorry...old sport.
Pilot | Caribou nibbling at the croquet hoops.
Mother | Yes, Mansfield shot one in the antlers.
Pilot | Oh, jolly good show. Is 'Becca about?
Mother | No, she's gorn off.
Pilot | What a super woody sort of phrase. `Gorn orff'.
Mother | Yes, she's gorn orff because Mansfield said tin to her.
Pilot | Oh, what rotten luck ... oh well ... whole afternoon to kill ... better have a bath I suppose.
Mother | Oh, Gervaise do sing me a song ...
Pilot | Oh, OK.
Mother | Something woody.
| The pilot launches into a quite enormously loud rendering of `She's going to marry Yum Yum'. The impact of this on the mother causes her to have a heart attack. She dies and the song ends.
Pilot | For ... she's going to marry Yum Yum ... oh crikey. The old song finished her orff.
Father | (entering) What's urp?
Pilot | I'm afraid Mrs Vermin Jones appears to have passed orn.
Father | Dead, is she?
Pilot | 'Fraid so.
Father | What a blow for her.
| Cut to the scene on a TV screen and pull out from the TV to Mrs Mock Tudor and Mrs Elizabeth III in their sitting room watching it.
Mrs Mock Tudor | What I want to know Mrs Elizabeth III, is why they give us crap like that, when there's bits of the Leicester by-pass what have never been shown. Biskwit?
Mrs Elizabeth III | (takes biskwit from plate) Oh, thank yew ...
| Mrs Mock Tudor switches her TV switch. The Arab boy winces in great pain and moves over to the set. He changes channels. Up comes a picture of the motorway again. Roller caption superimposed over the motorway. Appropriate 'Crossroads' type theme music.
Voice Over | (reading the roller caption) Appearing on the M2 were 4,281 Vauxhall Vivas, 2,117 Vauxhall Vivas de luxe, 153 Vauxhall Vivas with ...
| Mrs Elizabeth III throws the switch and the Arab boy winces with real pain and turns the knob of the television set which changes channels. On the TV set we see the same two ladies watching their set as before with the tramps on it. They continue watching until the two ladies on the set speak.
Mrs Mock Tudor | (on the TV set) Bloody repeats.
Mrs Mock Tudor | (not on the TV set) Bloody repeats.
| As before she switches switch. The Arab boy winces in pain and changes channels.
Mrs Elizabeth III | (on the TV set) Yes, repeats or war films ... makes you want to ...
| She throws the switch. The Arab boy winces in pain and turns over. The White City as for show-jumping. Close up of a mounted female rider waiting to start. Voice over of Dorian Williams.
Dorian | Hello and welcome to Show-Jumping from White City ...
Mrs Mock Tudor | Oh, moto-cross!
Dorian | ... and it's Anneli Drummond-Hay on Mr Softee just about to go into jump-off against the clock. The short pause is for the stewards who are repairing the Sound of Music. (cut to shot of stewards who are organizing eight nuns, Von Trapp in Tyrolean gear, Julie Andrews, and the six Von Trapp children into a group forming a fence; cut back to Anneli) ... Captain Phillips on 'Streuth' just caught one of the nuns at the very start of what would have been a fine clear round. It's a formidable obstacle this Sound of Music - eight nuns high but they're ready now, and singing. (the group start singing 'The Hills are Alive'; the bell goes for the start of the round and the lady rider sets of towards the group) And there's the bell. She's got 1.07 seconds to beat, but she needs a clear round to win. As she comes towards the Sound of Music and ...
| Cut away to the two ladies watching their TV. Shot from an angle so we can't see the screen.
Mrs Elizabeth III | Quite exciting.
| Cut back to White City to see the lady rider has just cleared the obstacle. A cheer from the crowd. The music changes to 'Oklahoma'. Follow her round to see a similar group dressed as for 'Oklahoma'. Ten hayseeds and six wenches with a hay wagon. Most have primitive pitch forks and are sucking on straws.
Dorian | ... beautifully taken, and now she needs to pick up speed for Oklahoma, but not too much. This is where Alan Jones knocked down poor Judd, but ... And ... she's taken it superbly!
Mrs Mock Tudor | You notice how we never actually see the horses jump.
| Cheer from TV. Cut back to White City. The horse is coming away from Oklahoma. Cut to run up to Black and White Minstrels.
Mrs Mock Tudor | Wait for it ...
| Cut back to White City.
Dorian | And! She's taken it ... (cheer; we actually see the lady jumper jump over the chorus of mistrels) She's over the Minstrels. She just flicked Leslie Crowther with her tail, but the time's good, and now she turns before coming into the final jump ... this is a tough one ... It's Ben-Hur - forty-six chariots ... 6,000 spectators ... 400 slaves, lion-handlers, the Emperor Nero and the entire Coliseum. 198 feet high. 400 years across!
| The lady jumper is now coming right towards the camera. Cut back to the ladies watching.
Mrs Mock Tudor | I bet we don't see this one.
| Cut back to horse actually jumping towards the camera. Cut to newsreader Peter Woods in a news studio.
Peter Woods | We interrupt show jumping to bring you a news flash. The Second World War has now entered a sentimental stage. The morning on the Ardennes Front, the Germans started spooning at dawn, but the British Fifth Army responded by gazing deep in their eyes, and the Germans are reported to have gone 'all coy'.
| Music comes in underneath: 'When Does a Dream Begin'. Mix to a young airman on an airfield gazing into a WAAF's eyes. Black and white, soft focus and scratched film to look like a not very good print of a 40's film. Airman sings.
Airman (Neil Innes) | When does a dream begin? Does it start with a goodnight kiss? Is it conceived or simply achieved When does a dream begin? Is it born in a moment of bliss? Or is it begun when two hearts are one When does a dream exist? The vision of you appears somehow Impossible to resist But I'm not imagining seeing you For who could have dreamed of this? When does a dream begin? When reality is dismissed? Or does it commence when we lose all pretence When does a dream begin?
| Mix sound to end of signiture tune. Halfway through the song the credits roll, superimposed. They read:
| MONTY PYTHON (SOCIAL CLASS 9) WAS PERFORMED BY GRAHAM CHAPMAN TERRY GILLIAM ERIC IDLE TERRY JONES MICHAEL PALIN (SOCIAL CLASS 2, ARSENAL 0) CONCEIVED AND WRITTEN BY GRAHAM CHAPMAN JOHN CLEESE TERRY GILLIAM ERIC IDLE NEIL INNES TERRY JONES MICHAEL PALIN (SOCIAL CLASS DERRY AND TOMS) ALSO APPEARING CAROL CLEVELAND BOB R. RAYMOND MARION MOULD (SOCIAL CLASS 47 ACTORS) 'WHEN DOES A DREAM BEGIN' BY NEIL INNES (SOCIAL CLASS 137 MUSICIANS) VARIATIONS ON THE THEME BY BILL MCGUFFIE (SOCIAL CLASS 137A OTHER MUSICIANS) MAKE-UP MAGGIE WESTON (SOCIAL CLASS 5 TILL MIDNIGHT) COSTUMES ANDREW ROSE (SOCIAL CLASS 35 28 34) FILM CAMERAMAN STAN SPEEL (SOCIAL CLASS F8 AT 25TH SEC.) SOUND RECORDIST RON BLIGHT (SOCIAL CLASS UNRECORDABLE) FILM EDITOR BOB DEARBERG (SOCIAL CLASS LOWER 6TH) (MR POTTER'S) SOUND MIKE JONES (SOCIAL CLASS SLIGHTLY ABOVE THE QUEEN) LIGHTING JIMMY PURDIE (SOCIAL CLASS A BOTTLE OF BELL'S) VISUAL EFFECTS JOHN HORTON (SOCIAL CLASS ANT) PRODUCTION ASSISTANT BRIAN JONES (SOCIAL BUT NO CLASS) DESIGNER ROBERT BERK (NO SOCIAL CLASS AT ALL) PRODUCED BY IAN MACNAUGHTON (SOCIAL CLASS 238-470 SCOTSMAN) BBC COLOUR (BY PERMISSION OF SIR K. JOSEPH)